assert_eq_or_update

Function assert_eq_or_update 

pub fn assert_eq_or_update(
    value: impl AsRef<str>,
    snapshot_path: impl AsRef<Path>,
)
Assert that value equals the snapshot at snapshot_path. If there is a mismatch the function will panic with a helpful diff that shows what changed.

Set the env var UPDATE_SNAPSHOTS=yes to write value to snapshot_file instead of asserting equality.